==> py3-bokeh-3.3.3.tgz: lib/python3.10/site-packages/bokeh/server/static/js/lib/styles/icons.css.d.ts <==
export const tool_icon_copy: string
export const tool_icon_replace_mode: string
export const tool_icon_append_mode: string
export const tool_icon_intersect_mode: string
export const tool_icon_subtract_mode: string
export const tool_icon_clear_selection: string
export const tool_icon_box_select: string
export const tool_icon_x_box_select: string
export const tool_icon_y_box_select: string
export const tool_icon_box_zoom: string
export const tool_icon_x_box_zoom: string
export const tool_icon_y_box_zoom: string
export const tool_icon_auto_box_zoom: string
export const tool_icon_zoom_in: string
export const tool_icon_zoom_out: string
export const tool_icon_help: string
export const tool_icon_hover: string
export const tool_icon_crosshair: string
export const tool_icon_lasso_select: string
export const tool_icon_pan: string
export const tool_icon_x_pan: string
export const tool_icon_y_pan: string
export const tool_icon_range: string
export const tool_icon_polygon_select: string
export const tool_icon_redo: string
export const tool_icon_reset: string
export const tool_icon_save: string
export const tool_icon_tap_select: string
export const tool_icon_undo: string
export const tool_icon_wheel_pan: string
export const tool_icon_wheel_zoom: string
export const tool_icon_box_edit: string
export const tool_icon_freehand_draw: string
export const tool_icon_poly_draw: string
export const tool_icon_point_draw: string
export const tool_icon_poly_edit: string
export const tool_icon_line_edit: string
export const tool_icon_settings: string
export const tool_icon_unknown: string
export const tool_icon_fullscreen: string
export const tool_icon_chevron_up: string
export const tool_icon_chevron_down: string
export const tool_icon_chevron_left: string
export const tool_icon_chevron_right: string
export const tool_icon_caret_up: string
export const tool_icon_caret_down: string
export const tool_icon_caret_left: string
export const tool_icon_caret_right: string
export const tool_icon_see_on: string
export const tool_icon_see_off: string
export default ""

==> py3-bokeh-3.4.1p0.tgz: lib/python3.11/site-packages/bokeh/server/static/js/lib/styles/icons.css.d.ts <==
export const tool_icon_copy: string
export const tool_icon_replace_mode: string
export const tool_icon_append_mode: string
export const tool_icon_intersect_mode: string
export const tool_icon_subtract_mode: string
export const tool_icon_xor_mode: string
export const tool_icon_invert_selection: string
export const tool_icon_clear_selection: string
export const tool_icon_box_select: string
export const tool_icon_x_box_select: string
export const tool_icon_y_box_select: string
export const tool_icon_box_zoom: string
export const tool_icon_x_box_zoom: string
export const tool_icon_y_box_zoom: string
export const tool_icon_auto_box_zoom: string
export const tool_icon_zoom_in: string
export const tool_icon_zoom_out: string
export const tool_icon_help: string
export const tool_icon_hover: string
export const tool_icon_crosshair: string
export const tool_icon_lasso_select: string
export const tool_icon_pan: string
export const tool_icon_x_pan: string
export const tool_icon_y_pan: string
export const tool_icon_range: string
export const tool_icon_polygon_select: string
export const tool_icon_redo: string
export const tool_icon_reset: string
export const tool_icon_save: string
export const tool_icon_tap_select: string
export const tool_icon_undo: string
export const tool_icon_wheel_pan: string
export const tool_icon_wheel_zoom: string
export const tool_icon_box_edit: string
export const tool_icon_freehand_draw: string
export const tool_icon_poly_draw: string
export const tool_icon_point_draw: string
export const tool_icon_poly_edit: string
export const tool_icon_line_edit: string
export const tool_icon_settings: string
export const tool_icon_unknown: string
export const tool_icon_fullscreen: string
export const tool_icon_chevron_up: string
export const tool_icon_chevron_down: string
export const tool_icon_chevron_left: string
export const tool_icon_chevron_right: string
export const tool_icon_caret_up: string
export const tool_icon_caret_down: string
export const tool_icon_caret_left: string
export const tool_icon_caret_right: string
export const tool_icon_see_on: string
export const tool_icon_see_off: string
export const tool_icon_x_grip: string
export const tool_icon_y_grip: string
export const tool_icon_arrow_down_to_bar: string
export const tool_icon_arrow_up_from_bar: string
export const tool_icon_minimize: string
export const tool_icon_maximize: string
export const tool_icon_pin: string
export const tool_icon_unpin: string
export const tool_icon_pointer: string
export const tool_icon_delete: string
export const tool_icon_bold: string
export const tool_icon_italic: string
export const tool_icon_text_align_left: string
export const tool_icon_text_align_center: string
export const tool_icon_text_align_right: string
export const tool_icon_check: string
export const tool_icon_square: string
export const tool_icon_square_check: string
export default ""
